import { Viewer } from '@grapecity/activereports/reportviewer';
import { Designer, templates } from '@grapecity/activereports/reportdesigner';
import { exportDocument } from '@grapecity/activereports/pdfexport';
import { exportDocument as exportDocument$1 } from '@grapecity/activereports/xlsxexport';
import { __awaiter } from 'tslib';
import { exportDocument as exportDocument$2 } from '@grapecity/activereports/htmlexport';
import { InjectionToken, Component, Input, ViewEncapsulation, EventEmitter, Output, Inject, Optional, ViewChild, NgModule, Injectable, defineInjectable } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/export-injectiontoken.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const AR_EXPORTS = new InjectionToken('AR_EXPORTS');
/**
 * @abstract
 */
class Export {
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/viewer/viewer.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ViewerComponent {
    /**
     * @param {?=} supportedExports
     */
    constructor(supportedExports) {
        this.supportedExports = supportedExports;
        this._initProps = [];
        this.width = '100%';
        this.height = '100%';
        this.availableExports = [];
        this.init = new EventEmitter();
        this.reportLoaded = new EventEmitter();
        this.documentLoaded = new EventEmitter();
        this._propSetters = {
            sidebarVisible: (/**
             * @param {?} value
             * @return {?}
             */
            (value) => { this._viewer.toggleSidebar(value); }),
            toolbarVisible: (/**
             * @param {?} value
             * @return {?}
             */
            (value) => { this._viewer.toggleToolbar(value); }),
            fullscreen: (/**
             * @param {?} value
             * @return {?}
             */
            (value) => { this._viewer.toggleFullScreen(value); }),
            availableExports: (/**
             * @param {?} value
             * @return {?}
             */
            (value) => {
                if (value && value.length > 0) {
                    /** @type {?} */
                    const supportedValues = value.filter((/**
                     * @param {?} v
                     * @return {?}
                     */
                    v => this.supportedExportKeys.indexOf(v) >= 0));
                    // set ['disabled'] to hide export panel if no exports supported
                    this._viewer.availableExports = supportedValues.length ? supportedValues : ['disabled'];
                }
                else {
                    // set explicit list to avoid side effects of global exports initialization
                    this._viewer.availableExports = this.supportedExportKeys.length ? this.supportedExportKeys : ['disabled'];
                }
            }),
            mouseMode: (/**
             * @param {?} value
             * @return {?}
             */
            (value) => { this._viewer.mouseMode = value; }),
            renderMode: (/**
             * @param {?} value
             * @return {?}
             */
            (value) => { this._viewer.renderMode = value; }),
            viewMode: (/**
             * @param {?} value
             * @return {?}
             */
            (value) => { this._viewer.viewMode = value; }),
            zoom: (/**
             * @param {?} value
             * @return {?}
             */
            (value) => { this._viewer.zoom = value; }),
            errorHandler: (/**
             * @param {?} value
             * @return {?}
             */
            (value) => { this._viewer.errorHandler = value; }),
        };
        this._disposables = [];
    }
    /**
     * @private
     * @return {?}
     */
    get supportedExportKeys() {
        return (this.supportedExports || []).map((/**
         * @param {?} e
         * @return {?}
         */
        e => e.key));
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        for (const prop of Object.keys(changes)) {
            /** @type {?} */
            const setter = this._propSetters[prop];
            if (!setter) {
                continue;
            }
            /** @type {?} */
            const value = changes[prop].currentValue;
            if (this._viewer) {
                setter(value);
            }
            else {
                this._initProps.push((/**
                 * @return {?}
                 */
                () => setter(value)));
            }
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.initViewer()
            .then((/**
         * @return {?}
         */
        () => this.init.emit(this)));
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        while (this._disposables.length) {
            (/** @type {?} */ (this._disposables.shift()))();
            this._viewer.dispose();
        }
    }
    /**
     * @return {?}
     */
    get ref() {
        return this._viewer;
    }
    /**
     * @private
     * @return {?}
     */
    initViewer() {
        return __awaiter(this, void 0, void 0, function* () {
            for (const supportedExport of this.supportedExports || []) {
                yield supportedExport.init();
            }
            this._viewer = new Viewer(this.rootElement.nativeElement, {
                language: this.language,
                PanelsLocation: this.panelsLayout != null ? this.panelsLayout : this.panelsLocation,
                ParameterPanelLocation: this.parameterPanelLocation,
                ToolbarLayout: this.toolbarLayout,
                ExportsSettings: this.exportsSettings,
            });
            this._disposables.push(this._viewer.reportLoaded.register((/**
             * @param {?} args
             * @return {?}
             */
            args => this.reportLoaded.emit(args))), this._viewer.documentLoaded.register((/**
             * @param {?} args
             * @return {?}
             */
            args => this.documentLoaded.emit(args))));
            this._propSetters.availableExports(this.availableExports);
            while (this._initProps.length) {
                (/** @type {?} */ (this._initProps.shift()))();
            }
        });
    }
    /**
     * Opens report from file or as definition (json string)).
     *
     * @param {?} report  The report template. Can be report URI, or report definition, or instance of PageReport class.
     * @param {?=} settings  Additional settings for report (name, parameters).
     * @return {?}
     */
    open(report, settings) {
        return this._viewer.open(report, settings);
    }
    /**
     * Exports currently displayed report to specified output format. Returns object which contains
     * result data as blob object | string and download function. So you could either use this blob object or download file immediately.
     * Please note that you can specify settings in PDF export as plain list
     * (like **{title: 'Title', author: 'Author Name', ownerPassword: '1'}** etc...
     *
     * ```javascript
     * var options = {filename:"Invoice List"};
     * var cancelCallback = function(){
     *     return false; // continue export. Return true to cancel export process
     * }
     * viewer.export('pdf', options, {cancel: cancelCallback }).then(result => doSmthWithBlob(result.data));
     * //or you can download file
     * viewer.export('pdf', options, {cancel: cancelCallback }).then(result => result.download('Invoice List'));
     * ```
     *
     * @param {?} format  Export format identifier. One of 'pdf', 'xlsx' or 'html'.
     * @param {?} settings  Format specific export settings.
     * @param {?=} params  Additional export customization.
     * @return {?}
     */
    export(format, settings, params) {
        return this._viewer.export(format, settings, params);
    }
    /**
     * Resets current viewer document
     * @return {?}
     */
    resetDocument() {
        return this._viewer.resetDocument();
    }
    /**
     * Prints currently displayed report.
     * @return {?}
     */
    print() {
        return this._viewer.print();
    }
    /**
     * Gets current page number (1-based). Returns 0 if no document loaded.
     * @return {?}
     */
    get currentPage() {
        return this._viewer.currentPage;
    }
    /**
     * Gets the total number of pages available in report.
     * @return {?}
     */
    get pageCount() {
        return this._viewer.pageCount;
    }
    /**
     * Provides access to the "history" API.
     * @return {?}
     */
    get history() {
        return this._viewer.history;
    }
    /**
     * Gets the toolbar API
     * @return {?}
     */
    get toolbar() {
        return this._viewer.toolbar;
    }
    /**
     * Navigates to the first page.
     * @return {?}
     */
    goToFirstPage() {
        return this._viewer.goToFirstPage();
    }
    /**
     * Navigates to the previous page.
     * @return {?}
     */
    goToPrevPage() {
        return this._viewer.goToPrevPage();
    }
    /**
     * Navigates to the next page.
     * @return {?}
     */
    goToNextPage() {
        return this._viewer.goToNextPage();
    }
    /**
     * Navigates to the last page.
     * @return {?}
     */
    goToLastPage() {
        return this._viewer.goToLastPage();
    }
    /**
     * Navigates to the specified page (starting from 1).
     * @param {?} pageNumber
     * @return {?}
     */
    goToPage(pageNumber) {
        return this._viewer.goToPage(pageNumber);
    }
    /**
     * Performs backToParent action which will return user to parent report.
     * @return {?}
     */
    backToParent() {
        return this._viewer.backToParent();
    }
    /**
     * Performs refresh operation in report (re-render report).
     * @return {?}
     */
    refresh() {
        return this._viewer.refresh();
    }
    /**
     * Gets **true** if backToParent command is applicable to current document.
     * @return {?}
     */
    get canBackToParent() {
        return this._viewer.canBackToParent();
    }
    /**
     * Register specified fonts in CSS and pdf export. Helps display export correctly on machines where fonts can be missed.
     * @param {...?} fonts
     * @return {?}
     */
    registerFont(...fonts) {
        return this._viewer.registerFont(...fonts);
    }
    /**
     * Performs search operation in currently rendered report. Allows you to create your own custom search pane.
     * @param {?} options
     * @param {?} resultFn
     * @param {?=} progressFn
     * @param {?=} cancel
     * @return {?}
     */
    search(options, resultFn, progressFn, cancel) {
        return this._viewer.search(options, resultFn, progressFn, cancel);
    }
    /**
     * Highlights the search result returned by a search method.
     * @param {?} result
     * @return {?}
     */
    highlight(result) {
        return this._viewer.highlight(result);
    }
}
ViewerComponent.decorators = [
    { type: Component, args: [{
                selector: 'gc-activereports-viewer',
                template: "<div #viewerRoot [style.width]=\"width\" [style.height]=\"height\"></div>",
                encapsulation: ViewEncapsulation.None
            }] }
];
/** @nocollapse */
ViewerComponent.ctorParameters = () => [
    { type: Array, decorators: [{ type: Inject, args: [AR_EXPORTS,] }, { type: Optional }] }
];
ViewerComponent.propDecorators = {
    rootElement: [{ type: ViewChild, args: ['viewerRoot',] }],
    width: [{ type: Input }],
    height: [{ type: Input }],
    language: [{ type: Input }],
    panelsLocation: [{ type: Input }],
    panelsLayout: [{ type: Input }],
    parameterPanelLocation: [{ type: Input }],
    toolbarLayout: [{ type: Input }],
    exportsSettings: [{ type: Input }],
    availableExports: [{ type: Input }],
    mouseMode: [{ type: Input }],
    renderMode: [{ type: Input }],
    viewMode: [{ type: Input }],
    zoom: [{ type: Input }],
    fullscreen: [{ type: Input }],
    toolbarVisible: [{ type: Input }],
    sidebarVisible: [{ type: Input }],
    errorHandler: [{ type: Input }],
    init: [{ type: Output }],
    reportLoaded: [{ type: Output }],
    documentLoaded: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/designer/designer.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @param {?=} report
 * @return {?}
 */
function isReportDef(report) {
    return !!(report && ((/** @type {?} */ (report))).definition);
}
/**
 * @param {?} curr
 * @param {?} prev
 * @return {?}
 */
function hasReportChanged(curr, prev) {
    /** @type {?} */
    const definitionChanged = (isReportDef(curr) && curr.definition) !== (isReportDef(curr) && curr.definition);
    return (definitionChanged || (curr && curr.id) !== (prev && prev.id) || (curr && curr.displayName) !== (prev && prev.displayName));
}
class DesignerComponent {
    constructor() {
        /**
         * Sets componets width
         */
        this.width = '100%';
        /**
         * Sets componets height
         */
        this.height = '100%';
        this._actionHandlers = {};
    }
    /**
     * Sets available set of fonts.
     * @param {?} value
     * @return {?}
     */
    set fontSet(value) {
        this._fontSet = value;
        if (this._designer)
            this._designer.fontSet = this._fontSet || 'all';
    }
    ;
    /**
     * Gets available set of fonts.
     * @return {?}
     */
    get fontSet() {
        return this._fontSet;
    }
    /**
     * Sets DataSource templates
     * @param {?} value List of DataSource templates
     * @return {?}
     */
    set dataSources(value) {
        this._dataSources = value;
        if (this._designer)
            this._designer.setDataSourceTemplates(this._dataSources || []);
    }
    /* Gets DataSource templates */
    /**
     * @return {?}
     */
    get dataSources() {
        return this._dataSources;
    }
    /**
     * Sets handler to be called on open report.
     * Handler return Promise with report info or 'undefined' if operation was cancelled.
     * @param {?} value
     * @return {?}
     */
    set onCreate(value) {
        this._actionHandlers.onCreate = value;
        if (this._designer)
            this._designer.setActionHandlers(this._actionHandlers);
    }
    /**
     * @return {?}
     */
    get onCreate() {
        return this._actionHandlers.onCreate;
    }
    /**
     * Sets handler to be called on opening report.
     * Handler returns Promise with report info or 'undefined' if operation was cancelled.
     * @param {?} value
     * @return {?}
     */
    set onOpen(value) {
        this._actionHandlers.onOpen = value;
        if (this._designer)
            this._designer.setActionHandlers(this._actionHandlers);
    }
    /**
     * @return {?}
     */
    get onOpen() {
        return this._actionHandlers.onOpen;
    }
    /**
     * Sets handler to be called on request to render current report.
     * @param {?} value
     * @return {?}
     */
    set onRender(value) {
        this._actionHandlers.onRender = value;
        if (this._designer)
            this._designer.setActionHandlers(this._actionHandlers);
    }
    /**
     * @return {?}
     */
    get onRender() {
        return this._actionHandlers.onRender;
    }
    /**
     * Sets handler to be called on saving report.
     * Handler returns Promise with new report info if report was saved or 'undefined' if operation was cancelled.
     * @param {?} value
     * @return {?}
     */
    set onSave(value) {
        this._actionHandlers.onSave = value;
        if (this._designer)
            this._designer.setActionHandlers(this._actionHandlers);
    }
    /**
     * @return {?}
     */
    get onSave() {
        return this._actionHandlers.onSave;
    }
    /**
     * Sets handler to be called on saving report as new.
     * Handler returns Promise with new report info if report was saved or 'undefined' if operation was cancelled.
     * @param {?} value
     * @return {?}
     */
    set onSaveAs(value) {
        this._actionHandlers.onSaveAs = value;
        if (this._designer)
            this._designer.setActionHandlers(this._actionHandlers);
    }
    /**
     * @return {?}
     */
    get onSaveAs() {
        return this._actionHandlers.onSaveAs;
    }
    /**
     * Sets handler to be called on open custom file menu.
     * @param {?} value
     * @return {?}
     */
    set onOpenFileMenu(value) {
        this._actionHandlers.onOpenFileMenu = value;
        if (this._designer)
            this._designer.setActionHandlers(this._actionHandlers);
    }
    /**
     * @return {?}
     */
    get onOpenFileMenu() {
        return this._actionHandlers.onOpenFileMenu;
    }
    /**
     * Watch report property
     * @param {?} value
     * @return {?}
     */
    set report(value) {
        if (hasReportChanged(value, this._report)) {
            this._report = value;
            this.setReport(value || { definition: templates.CPL }, 'override');
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        /** @type {?} */
        const config = {
            disableOpenSaveHotkeys: this.hotkeysEnabled === false,
            language: this.language,
            customInitTemplates: this.customInitTemplates,
        };
        this._designer = new Designer(this.rootElement.nativeElement, config);
        this._designer.setResourceProvider({
            getImagesList: (/**
             * @return {?}
             */
            () => __awaiter(this, void 0, void 0, function* () { return this.imageList || []; })),
            getReportsList: (/**
             * @return {?}
             */
            () => __awaiter(this, void 0, void 0, function* () { return this.reportList || []; })),
            getThemesList: (/**
             * @return {?}
             */
            () => __awaiter(this, void 0, void 0, function* () { return this.themeList || []; })),
        });
        this._designer.setActionHandlers(this._actionHandlers);
        if (this.fontSet)
            this._designer.fontSet = this.fontSet;
        if (this.dataSources)
            this._designer.setDataSourceTemplates(this._dataSources || []);
        if (this._report)
            this.setReport(this._report || { definition: templates.CPL }, 'override');
    }
    /**
     * Sets report.
     * @param {?} report Report info to load.
     * @param {?=} whenDirty Action to perform in case of 'dirty' report.
     * @return {?}
     */
    setReport(report, whenDirty) {
        if (!this._designer)
            return Promise.resolve();
        return this._designer.setReport(report, whenDirty);
    }
    /**
     * Gets current report.
     * @return {?}
     */
    getReport() {
        if (!this._designer)
            return (/** @type {?} */ (Promise.resolve()));
        return this._designer.getReport();
    }
    /**
     * Process command.
     * @param {?} cmd Command name.
     * @return {?}
     */
    processCommand(cmd) {
        if (!this._designer)
            return Promise.resolve();
        return this._designer.processCommand(cmd);
    }
}
DesignerComponent.decorators = [
    { type: Component, args: [{
                selector: 'gc-activereports-designer',
                template: "<div #designerRoot [style.width]=\"width\" [style.height]=\"height\"></div>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
DesignerComponent.ctorParameters = () => [];
DesignerComponent.propDecorators = {
    rootElement: [{ type: ViewChild, args: ['designerRoot',] }],
    width: [{ type: Input }],
    height: [{ type: Input }],
    hotkeysEnabled: [{ type: Input }],
    language: [{ type: Input }],
    customInitTemplates: [{ type: Input }],
    fontSet: [{ type: Input }],
    dataSources: [{ type: Input }],
    reportList: [{ type: Input }],
    imageList: [{ type: Input }],
    themeList: [{ type: Input }],
    onCreate: [{ type: Input }],
    onOpen: [{ type: Input }],
    onRender: [{ type: Input }],
    onSave: [{ type: Input }],
    onSaveAs: [{ type: Input }],
    onOpenFileMenu: [{ type: Input }],
    report: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/activereports.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ActiveReportsModule {
}
ActiveReportsModule.decorators = [
    { type: NgModule, args: [{
                declarations: [ViewerComponent, DesignerComponent],
                imports: [],
                exports: [ViewerComponent, DesignerComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/pdf-export.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class PdfExportService extends Export {
    constructor() {
        super();
        this.key = 'pdf';
    }
    /**
     * @return {?}
     */
    init() {
        return __awaiter(this, void 0, void 0, function* () {
            // 'exportDocument' must be used to avoid tree-shaking
            if (typeof exportDocument !== 'function') {
                console.error(`Invalid "${this.key}" export module.`);
            }
        });
    }
}
PdfExportService.decorators = [
    { type: Injectable, args: [{
                providedIn: ViewerComponent
            },] }
];
/** @nocollapse */
PdfExportService.ctorParameters = () => [];
/** @nocollapse */ PdfExportService.ngInjectableDef = defineInjectable({ factory: function PdfExportService_Factory() { return new PdfExportService(); }, token: PdfExportService, providedIn: ViewerComponent });

/**
 * @fileoverview added by tsickle
 * Generated from: lib/xlsx-export.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class XlsxExportService extends Export {
    constructor() {
        super();
        this.key = 'xlsx';
    }
    /**
     * @return {?}
     */
    init() {
        return __awaiter(this, void 0, void 0, function* () {
            // 'exportDocument' must be used to avoid tree-shaking
            if (typeof exportDocument$1 !== 'function') {
                console.error(`Invalid "${this.key}" export module.`);
            }
        });
    }
}
XlsxExportService.decorators = [
    { type: Injectable, args: [{
                providedIn: ViewerComponent
            },] }
];
/** @nocollapse */
XlsxExportService.ctorParameters = () => [];
/** @nocollapse */ XlsxExportService.ngInjectableDef = defineInjectable({ factory: function XlsxExportService_Factory() { return new XlsxExportService(); }, token: XlsxExportService, providedIn: ViewerComponent });

/**
 * @fileoverview added by tsickle
 * Generated from: lib/html-export.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class HtmlExportService extends Export {
    constructor() {
        super();
        this.key = 'html';
    }
    /**
     * @return {?}
     */
    init() {
        return __awaiter(this, void 0, void 0, function* () {
            // 'exportDocument' must be used to avoid tree-shaking
            if (typeof exportDocument$2 !== 'function') {
                console.error(`Invalid "${this.key}" export module.`);
            }
        });
    }
}
HtmlExportService.decorators = [
    { type: Injectable, args: [{
                providedIn: ViewerComponent
            },] }
];
/** @nocollapse */
HtmlExportService.ctorParameters = () => [];
/** @nocollapse */ HtmlExportService.ngInjectableDef = defineInjectable({ factory: function HtmlExportService_Factory() { return new HtmlExportService(); }, token: HtmlExportService, providedIn: ViewerComponent });

/**
 * @fileoverview added by tsickle
 * Generated from: public-api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: grapecity-activereports-angular.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { ViewerComponent, DesignerComponent, ActiveReportsModule, PdfExportService, XlsxExportService, HtmlExportService, AR_EXPORTS, Export };

//# sourceMappingURL=grapecity-activereports-angular.js.map