import { AfterViewInit, ElementRef } from '@angular/core';
import { Report, WhenDirty, ImageResourceInfo, ReportResourceInfo, ThemeResourceInfo, DesignerCommand, ReportInfo } from '@grapecity/activereports/reportdesigner';
export declare class DesignerComponent implements AfterViewInit {
    rootElement: ElementRef;
    private _designer?;
    constructor();
    /** Sets componets width */
    width: string;
    /** Sets componets height */
    height: string;
    /** If set to 'false' disables default open and save report hotkeys. */
    hotkeysEnabled?: boolean;
    /**
       * Application language, for example 'en', 'ja or 'zh'.
       * Default value is 'en'.
      */
    language?: string;
    /** Templates with default values for report and report items. */
    customInitTemplates?: {
        imperialTemplates?: string[];
        metricTemplates?: string[];
    };
    private _fontSet?;
    /** Sets available set of fonts. */
    /** Gets available set of fonts. */
    fontSet: any;
    private _dataSources?;
    /**
     * Sets DataSource templates
     * @param value List of DataSource templates
     */
    /* Gets DataSource templates */
    dataSources: any;
    /** Sets external report list. */
    reportList?: ReportResourceInfo[];
    /** Sets external image list. */
    imageList?: ImageResourceInfo[];
    /** Sets theme list. */
    themeList?: ThemeResourceInfo[];
    private _actionHandlers;
    /**
     * Sets handler to be called on open report.
     * Handler return Promise with report info or 'undefined' if operation was cancelled.
     */
    onCreate: any;
    /**
     * Sets handler to be called on opening report.
     * Handler returns Promise with report info or 'undefined' if operation was cancelled.
     */
    onOpen: any;
    /**
     * Sets handler to be called on request to render current report.
     */
    onRender: any;
    /**
     * Sets handler to be called on saving report.
     * Handler returns Promise with new report info if report was saved or 'undefined' if operation was cancelled.
     */
    onSave: any;
    /**
     * Sets handler to be called on saving report as new.
     * Handler returns Promise with new report info if report was saved or 'undefined' if operation was cancelled.
     */
    onSaveAs: any;
    /**
     * Sets handler to be called on open custom file menu.
     */
    onOpenFileMenu: any;
    private _report;
    /**
     * Watch report property
    */
    report: Report;
    ngAfterViewInit(): void;
    /**
     * Sets report.
     * @param report Report info to load.
     * @param whenDirty Action to perform in case of 'dirty' report.
     */
    setReport(report: Report, whenDirty?: WhenDirty): Promise<void>;
    /** Gets current report. */
    getReport(): Promise<ReportInfo>;
    /**
     * Process command.
     * @param cmd Command name.
     */
    processCommand(cmd: DesignerCommand): Promise<void>;
}
